summaryrefslogtreecommitdiff
path: root/share/common.nix
diff options
context:
space:
mode:
Diffstat (limited to 'share/common.nix')
-rw-r--r--share/common.nix11
1 files changed, 3 insertions, 8 deletions
diff --git a/share/common.nix b/share/common.nix
index 00ad551..5ccd71e 100644
--- a/share/common.nix
+++ b/share/common.nix
@@ -208,19 +208,14 @@ in
# use X11/wayland layout for console, too
console.useXkbConfig = true;
# enable greetd & the KDE Plasma Desktop Environment
services.desktopManager.plasma6.enable = true;
- services.greetd = {
+ services.displayManager.sddm = {
enable = true;
- settings = {
- default_session = {
- command = "${pkgs.greetd.tuigreet}/bin/tuigreet --time --cmd '${pkgs.kdePackages.plasma-workspace}/libexec/plasma-dbus-run-session-if-needed ${pkgs.kdePackages.plasma-workspace}/bin/startplasma-wayland'";
- };
- };
+ wayland.enable = true;
};
# enable sound with PipeWire
- sound.enable = true;
hardware.pulseaudio.enable = false;
services.pipewire = {
enable = true;
@@ -208,19 +208,14 @@ in
# use X11/wayland layout for console, too
console.useXkbConfig = true;
- # enable greetd & the KDE Plasma Desktop Environment
+ # enable SDDM & the KDE Plasma Desktop Environment with Wayland
services.desktopManager.plasma6.enable = true;